@@ -1,3 +1,6 @@
+'''
+IO utils
+'''
 import json
 from pathlib import Path
 import torch
@@ -12,28 +15,38 @@ FINETUNED_MODEL = MODEL_DIR / 'fine-tuned/fine-tuned-uncased'
 FINETUNED_MODEL_STATE = MODEL_DIR / 'fine-tuned/model-state-dict'
 FINETUNED_OPT_STATE = MODEL_DIR / 'fine-tuned/opt-state-dict'
 CHECKPOINT_DIR = MODEL_DIR / 'checkpoint'
+LABEL_DICT = MODEL_DIR / 'fine-tuned/labels-dict.json'
 
 
-def get_pretrained_tokenizer(MODEL_NAME=MODEL_NAME, PRETRAINED_TOKENIZER=PRETRAINED_TOKENIZER):
-    if PRETRAINED_TOKENIZER.exists():
-        pretrained_tokenizer = BertTokenizer.from_pretrained(PRETRAINED_TOKENIZER)
+def get_pretrained_tokenizer(model_name=MODEL_NAME, pretrained_tokenizer_dir=PRETRAINED_TOKENIZER):
+    '''
+    get pretrained tokenizer
+    '''
+    if pretrained_tokenizer_dir.exists():
+        pretrained_tokenizer = BertTokenizer.from_pretrained(pretrained_tokenizer_dir)
     else:
-        pretrained_tokenizer = BertTokenizer.from_pretrained(MODEL_NAME)
-        pretrained_tokenizer.save_pretrained(PRETRAINED_TOKENIZER)
+        pretrained_tokenizer = BertTokenizer.from_pretrained(model_name)
+        pretrained_tokenizer.save_pretrained(pretrained_tokenizer_dir)
     return pretrained_tokenizer
 
 
-def get_pretrained_model(MODEL_NAME=MODEL_NAME, PRETRAINED_MODEL=PRETRAINED_MODEL):
-    if PRETRAINED_MODEL.exists():
-        pretrained_model = BertModel.from_pretrained(PRETRAINED_MODEL)
+def get_pretrained_model(model_name=MODEL_NAME, pretrained_model_dir=PRETRAINED_MODEL):
+    '''
+    get pretrained model
+    '''
+    if pretrained_model_dir.exists():
+        pretrained_model = BertModel.from_pretrained(pretrained_model_dir)
     else:
-        pretrained_model = BertModel.from_pretrained(MODEL_NAME)
-        pretrained_model.save_pretrained(PRETRAINED_MODEL)
+        pretrained_model = BertModel.from_pretrained(model_name)
+        pretrained_model.save_pretrained(pretrained_model_dir)
     return pretrained_model
 
 
 def save_checkpoint(model, optimizer, epoch, train_loss, train_accuracy, val_loss, val_accuracy):
-    PATH = CHECKPOINT_DIR / ('chkpt' + epoch + '.pt')
+    '''
+    save checkpoint
+    '''
+    chkpt_path = CHECKPOINT_DIR / ('chkpt' + epoch + '.pt')
     torch.save({
         'epoch': epoch,
         'model_state_dict': model.state_dict(),
@@ -42,10 +55,13 @@ def save_checkpoint(model, optimizer, epoch, train_loss, train_accuracy, val_los
         'val_loss': val_loss,
         'train_acc': train_accuracy,
         'val_acc': val_accuracy,
-    }, PATH)
+    }, chkpt_path)
 
 
 def load_checkpoint(model, optimizer, chkpoint_dir):
+    '''
+    load checkpoint
+    '''
     checkpoint = torch.load(chkpoint_dir)
     model.load_state_dict(checkpoint['model_state_dict'])
     optimizer.load_state_dict(checkpoint['optimizer_state_dict'])
@@ -57,7 +73,10 @@ def load_checkpoint(model, optimizer, chkpoint_dir):
     return model, optimizer, epoch, train_loss, val_loss, train_acc, val_acc
 
 
-def save_model(model, optimizer, pretrained_model):
+def save_model(model, optimizer):
+    '''
+    save model para
+    '''
     torch.save(model.state_dict(), FINETUNED_MODEL_STATE)
     torch.save(optimizer.state_dict(), FINETUNED_OPT_STATE)
     # loaded_model = BertClass(pretrained_model, model.l3.out_features)
@@ -66,6 +85,9 @@ def save_model(model, optimizer, pretrained_model):
 
 
 def load_model(model_dir=FINETUNED_MODEL, device='cpu'):
+    '''
+    load the whole model
+    '''
     return torch.load(model_dir, map_location=torch.device(device))
 
 
@@ -76,11 +98,13 @@ def load_model(model_dir=FINETUNED_MODEL, device='cpu'):
 #     return model
 
 
-def save_label_dict(label_dict, dir='../models/bert/fine-tuned/labels-dict.json'):
-    with open(dir, 'w') as f:
-        json.dump(label_dict, f)
+def save_label_dict(label_dict, dict_file=LABEL_DICT):
+    '''save label dictionary'''
+    with open(dict_file, 'w') as file:
+        json.dump(label_dict, file)
 
 
 def load_label_dict(label_dir):
-    with open(dir, 'r') as f:
-        return json.load(f)
+    '''load label dictionary'''
+    with open(label_dir, 'r') as file:
+        return json.load(file)
